@@ -34,7 +34,16 @@ our $GLOBAL       = {};
 our $BASE_SCOPE   = Perlito5::Grammar::Scope->new_base_scope();
 our $SCOPE        = $BASE_SCOPE;    # information about the current block being compiled
 our $SCOPE_DEPTH  = 0;
-our @SCOPE_STMT = ();
+our @SCOPE_STMT      = ();
+our @END_BLOCK       = ();    # END block LIFO - array of subs
+our @INIT_BLOCK      = ();    # INIT block FIFO - array of subs
+our @CHECK_BLOCK     = ();    # CHECK block LIFO - array of subs
+our @UNITCHECK_BLOCK = ();    # UNITCHECK block LIFO - array of subs
+
+sub set_global_phase {
+    my $phase = shift;
+    eval { ${^GLOBAL_PHASE} = $phase };
+}
 
 our $ID           = 100;    # generic "id" source; increment after use
 
